class HelloWorld:
    """ HelloWorld class will tell you hello!

    """
    def __init__(self, firstname, lastname):
        """ initialize HelloWorld class

        Args:
           firstname (str): first name of user
           lastname (str): last name of user
        """
        self.firstname = firstname
        self.lastname = lastname

    @property
    def hello(self):
        """ say hello to user

        a longer message about what this function does

        Returns:
            str: special hello message to user
        """
        return f'Hello {self.firstname} {self.lastname}'

    @staticmethod
    def helloworld(name):
        """string with special hello message to name

        Args:
            name (str): the person to say hello to

        Returns:
            str: special hello world message
        """
        return f'Hello World {name}!'


def fizzbuzz(n):
    """A super advanced fizzbuzz function

    Write a program that prints the numbers from 1 to 100. But for
    multiples of three print “Fizz” instead of the number and for the
    multiples of five print “Buzz”. For numbers which are multiples of
    both three and five print “FizzBuzz” Prints out fizz and buzz

    Args:
        n (int): number for fizzbuzz to count to

    Returns:
       None: prints to stdout fizzbuzz
    """
    def _fizzbuzz(i):
        if i % 3 == 0 and i % 5 == 0:
            return 'FizzBuzz'
        elif i % 3 == 0:
            return 'Fizz'
        elif i % 5 == 0:
            return 'Buzz'
        else:
            return str(i)
    print("\n".join(_fizzbuzz(i+1) for i in range(n)))



import argparse
import sys


def main():
    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers()
    add_subcommand_fizzbuzz(subparsers)
    if len(sys.argv) == 1:
        parser.print_help()
        sys.exit(1)
    args = parser.parse_args()
    args.func(args)


def add_subcommand_fizzbuzz(subparsers):
    parser = subparsers.add_parser('fizzbuzz', help='do the fizzbuzz!')
    parser.set_defaults(func=handle_subcommand_fizzbuzz)
    parser.add_argument('-n', '--number', type=int, default=100, help='number for fizzbuzz to count to')


def handle_subcommand_fizzbuzz(args):
    from pypkgtemp.hello import fizzbuzz
    fizzbuzz(args.number)


if __name__ == '__main__':
    main()



# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='pypkgtemp',
    version='1.2.0',
    description='A python package template',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://gitlab.com/costrouc/knoxpy-sqlite-pypi-readthedocs',
    author='Chris Ostrouchov',
    author_email='chris.ostrouchov+pypkgtemp@gmail.com',
    license="MIT",
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6'
    ],
    keywords='python package template documentation testing continuous deployment',
    packages=find_packages(exclude=['docs', 'tests']),
    setup_requires=['pytest-runner', 'setuptools>=38.6.0'],  # >38.6.0 needed for markdown README.md
    tests_require=['pytest', 'pytest-cov'],
    entry_points={
        'console_scripts': [
            'helloworld=pypkgtemp.__main__:main'
        ]
    }
)
